EXPORTS
	??1CRoutingSoundPlayDevice@@UAE@XZ @ 1 NONAME ; CRoutingSoundPlayDevice::~CRoutingSoundPlayDevice(void)
	??1CRoutingSoundRecordDevice@@UAE@XZ @ 2 NONAME ; CRoutingSoundRecordDevice::~CRoutingSoundRecordDevice(void)
	?BytesPlayed@CRoutingSoundPlayDevice@@QAEIXZ @ 3 NONAME ; unsigned int CRoutingSoundPlayDevice::BytesPlayed(void)
	?BytesRecorded@CRoutingSoundRecordDevice@@QAEIXZ @ 4 NONAME ; unsigned int CRoutingSoundRecordDevice::BytesRecorded(void)
	?CancelInitialize@CRoutingSoundPlayDevice@@QAEXVTUid@@@Z @ 5 NONAME ; void CRoutingSoundPlayDevice::CancelInitialize(class TUid)
	?CancelInitialize@CRoutingSoundRecordDevice@@QAEXVTUid@@@Z @ 6 NONAME ; void CRoutingSoundRecordDevice::CancelInitialize(class TUid)
	?CancelNotifyError@CRoutingSoundPlayDevice@@QAEXXZ @ 7 NONAME ; void CRoutingSoundPlayDevice::CancelNotifyError(void)
	?CancelNotifyError@CRoutingSoundRecordDevice@@QAEXXZ @ 8 NONAME ; void CRoutingSoundRecordDevice::CancelNotifyError(void)
	?CancelOpenDevice@CRoutingSoundPlayDevice@@QAEXVTUid@@@Z @ 9 NONAME ; void CRoutingSoundPlayDevice::CancelOpenDevice(class TUid)
	?CancelOpenDevice@CRoutingSoundRecordDevice@@QAEXVTUid@@@Z @ 10 NONAME ; void CRoutingSoundRecordDevice::CancelOpenDevice(class TUid)
	?CancelPlayData@CRoutingSoundPlayDevice@@QAEXXZ @ 11 NONAME ; void CRoutingSoundPlayDevice::CancelPlayData(void)
	?CancelRecordData@CRoutingSoundRecordDevice@@QAEXXZ @ 12 NONAME ; void CRoutingSoundRecordDevice::CancelRecordData(void)
	?CloseDevice@CRoutingSoundPlayDevice@@QAEXVTUid@@AAVTRequestStatus@@@Z @ 13 NONAME ; void CRoutingSoundPlayDevice::CloseDevice(class TUid, class TRequestStatus &)
	?CloseDevice@CRoutingSoundRecordDevice@@QAEXVTUid@@AAVTRequestStatus@@@Z @ 14 NONAME ; void CRoutingSoundRecordDevice::CloseDevice(class TUid, class TRequestStatus &)
	?FlushBuffer@CRoutingSoundPlayDevice@@QAEXXZ @ 15 NONAME ; void CRoutingSoundPlayDevice::FlushBuffer(void)
	?FlushBuffer@CRoutingSoundRecordDevice@@QAEXXZ @ 16 NONAME ; void CRoutingSoundRecordDevice::FlushBuffer(void)
	?Gain@CRoutingSoundRecordDevice@@QBEIXZ @ 17 NONAME ; unsigned int CRoutingSoundRecordDevice::Gain(void) const
	?GetSupportedChannels@CRoutingSoundPlayDevice@@QAEHAAV?$RArray@I@@AAW4TMMFStereoSupport@@@Z @ 18 NONAME ; int CRoutingSoundPlayDevice::GetSupportedChannels(class RArray<unsigned int> &, enum TMMFStereoSupport &)
	?GetSupportedChannels@CRoutingSoundRecordDevice@@QAEHAAV?$RArray@I@@AAW4TMMFStereoSupport@@@Z @ 19 NONAME ; int CRoutingSoundRecordDevice::GetSupportedChannels(class RArray<unsigned int> &, enum TMMFStereoSupport &)
	?GetSupportedDataTypes@CRoutingSoundPlayDevice@@QAEHAAV?$RArray@VTFourCC@@@@@Z @ 20 NONAME ; int CRoutingSoundPlayDevice::GetSupportedDataTypes(class RArray<class TFourCC> &)
	?GetSupportedSampleRates@CRoutingSoundPlayDevice@@QAEHAAV?$RArray@I@@AAV?$RArray@VTRange@@@@@Z @ 21 NONAME ; int CRoutingSoundPlayDevice::GetSupportedSampleRates(class RArray<unsigned int> &, class RArray<class TRange> &)
	?GetSupportedSampleRates@CRoutingSoundRecordDevice@@QAEHAAV?$RArray@I@@AAV?$RArray@VTRange@@@@@Z @ 22 NONAME ; int CRoutingSoundRecordDevice::GetSupportedSampleRates(class RArray<unsigned int> &, class RArray<class TRange> &)
	?Handle@CRoutingSoundPlayDevice@@QBEHXZ @ 23 NONAME ; int CRoutingSoundPlayDevice::Handle(void) const
	?Handle@CRoutingSoundRecordDevice@@QBEHXZ @ 24 NONAME ; int CRoutingSoundRecordDevice::Handle(void) const
	?Initialize@CRoutingSoundPlayDevice@@QAEXVTUid@@ABVTDesC8@@AAVTRequestStatus@@@Z @ 25 NONAME ; void CRoutingSoundPlayDevice::Initialize(class TUid, class TDesC8 const &, class TRequestStatus &)
	?Initialize@CRoutingSoundRecordDevice@@QAEXVTUid@@ABVTDesC8@@AAVTRequestStatus@@@Z @ 26 NONAME ; void CRoutingSoundRecordDevice::Initialize(class TUid, class TDesC8 const &, class TRequestStatus &)
	?NewL@CRoutingSoundPlayDevice@@SAPAV1@XZ @ 27 NONAME ; class CRoutingSoundPlayDevice * CRoutingSoundPlayDevice::NewL(void)
	?NewL@CRoutingSoundRecordDevice@@SAPAV1@XZ @ 28 NONAME ; class CRoutingSoundRecordDevice * CRoutingSoundRecordDevice::NewL(void)
	?NotifyError@CRoutingSoundPlayDevice@@QAEXAAVTRequestStatus@@@Z @ 29 NONAME ; void CRoutingSoundPlayDevice::NotifyError(class TRequestStatus &)
	?NotifyError@CRoutingSoundRecordDevice@@QAEXAAVTRequestStatus@@@Z @ 30 NONAME ; void CRoutingSoundRecordDevice::NotifyError(class TRequestStatus &)
	?OpenDevice@CRoutingSoundPlayDevice@@QAEXVTUid@@AAVTRequestStatus@@@Z @ 31 NONAME ; void CRoutingSoundPlayDevice::OpenDevice(class TUid, class TRequestStatus &)
	?OpenDevice@CRoutingSoundRecordDevice@@QAEXVTUid@@AAVTRequestStatus@@@Z @ 32 NONAME ; void CRoutingSoundRecordDevice::OpenDevice(class TUid, class TRequestStatus &)
	?PauseBuffer@CRoutingSoundPlayDevice@@QAEHXZ @ 33 NONAME ; int CRoutingSoundPlayDevice::PauseBuffer(void)
	?PlayData@CRoutingSoundPlayDevice@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 34 NONAME ; void CRoutingSoundPlayDevice::PlayData(class TDesC8 const &, class TRequestStatus &)
	?RecordData@CRoutingSoundRecordDevice@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 35 NONAME ; void CRoutingSoundRecordDevice::RecordData(class TDes8 &, class TRequestStatus &)
	?ResetBytesPlayed@CRoutingSoundPlayDevice@@QAEHXZ @ 36 NONAME ; int CRoutingSoundPlayDevice::ResetBytesPlayed(void)
	?ResumePlaying@CRoutingSoundPlayDevice@@QAEHXZ @ 37 NONAME ; int CRoutingSoundPlayDevice::ResumePlaying(void)
	?SetBufferSize@CRoutingSoundPlayDevice@@QAEHI@Z @ 38 NONAME ; int CRoutingSoundPlayDevice::SetBufferSize(unsigned int)
	?SetBufferSize@CRoutingSoundRecordDevice@@QAEHI@Z @ 39 NONAME ; int CRoutingSoundRecordDevice::SetBufferSize(unsigned int)
	?SetChannels@CRoutingSoundPlayDevice@@QAEHIW4TMMFStereoSupport@@@Z @ 40 NONAME ; int CRoutingSoundPlayDevice::SetChannels(unsigned int, enum TMMFStereoSupport)
	?SetChannels@CRoutingSoundRecordDevice@@QAEHIW4TMMFStereoSupport@@@Z @ 41 NONAME ; int CRoutingSoundRecordDevice::SetChannels(unsigned int, enum TMMFStereoSupport)
	?SetDataType@CRoutingSoundPlayDevice@@QAEHABVTFourCC@@@Z @ 42 NONAME ; int CRoutingSoundPlayDevice::SetDataType(class TFourCC const &)
	?SetGain@CRoutingSoundRecordDevice@@QAEHI@Z @ 43 NONAME ; int CRoutingSoundRecordDevice::SetGain(unsigned int)
	?SetSampleRate@CRoutingSoundPlayDevice@@QAEHI@Z @ 44 NONAME ; int CRoutingSoundPlayDevice::SetSampleRate(unsigned int)
	?SetSampleRate@CRoutingSoundRecordDevice@@QAEHI@Z @ 45 NONAME ; int CRoutingSoundRecordDevice::SetSampleRate(unsigned int)
	?SetVolume@CRoutingSoundPlayDevice@@QAEHI@Z @ 46 NONAME ; int CRoutingSoundPlayDevice::SetVolume(unsigned int)
	?Volume@CRoutingSoundPlayDevice@@QBEIXZ @ 47 NONAME ; unsigned int CRoutingSoundPlayDevice::Volume(void) const

